BooleanPropertyStream class

A property stream for JSON boolean values.

Provides a future that completes with the parsed boolean value.

Inheritance

Constructors

BooleanPropertyStream({required Future<bool> future, required Stream<bool> stream, required JsonStreamParserController parserController, required String propertyPath})

Properties

asBool BooleanPropertyStream
no setterinherited
asList ListPropertyStream<Object?>
no setterinherited
asMap MapPropertyStream
no setterinherited
asNull NullPropertyStream
no setterinherited
asNum NumberPropertyStream
no setterinherited
asStr StringPropertyStream
no setterinherited
future Future<bool>
A future that completes with the final parsed value of this property.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<bool>
A stream that emits the boolean value when parsing is complete.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onLog(void callback(ParseEvent event)) → void
Registers a callback to receive log events for this property and its descendants.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited